import streamlit as st

if 'current_page' not in st.session_state:
    st.session_state['current_page'] = 'page1'


def goto_page_1():
    st.session_state['current_page'] = 'page1'


def goto_page_2():
    st.session_state['current_page'] = 'page2'


def render_page_1():
    st.write('Page 1!')
    st.button(label='go to page 2', on_click=goto_page_2)


def render_page_2():
    st.write('Page 2!')
    st.button(label='go to page 1', on_click=goto_page_1)


if st.session_state['current_page'] == 'page1':
    print('render page 1!')
    render_page_1()
else:
    render_page_2()



# from functools import partial
# import json
# import os
# from plunk.tw.py2py_front_example.simple_pycode import foo, bar, confuser
# import streamlit.bootstrap
# from py2http import mk_app, run_app
# from py2http.util import run_process
#
# run_streamlit = partial(streamlit.bootstrap.run, command_line='', flag_options={})
# funcs = [foo, bar, confuser]
#
# if __name__ == '__main__':
#     with run_process(
#         func=run_app,
#         func_kwargs=dict(
#             app_obj=funcs,
#             publish_openapi=True,
#         ),
#         is_ready=3
#     ):
#         app = mk_app(funcs)
#         openapi_spec = json.dumps(app.openapi_spec)
#         dirname = os.path.dirname(__file__)
#         filename = os.path.join(dirname, 'run_streamlitfront.py')
#         run_streamlit(filename, args=[openapi_spec])



"""Example app 2"""

from streamlitfront import dispatch_funcs


def foo_2(a: int = 0, b: int = 0, c=0):
    """This is foo. It computes something"""
    return (a * b) + c


def bar_2(x, greeting='hello'):
    """bar greets its input"""
    return f'{greeting} {x}'


def confuser_2(a: int = 0, x: float = 3.14):
    return (a ** 2) * x


dispatch_funcs([foo_2, bar_2, confuser_2])()



from functools import wraps
import json
from sys import argv
from streamlitfront.base import dispatch_funcs
from http2py import HttpClient
from i2.wrapper import Sig


def flatten(meth):
    sig = Sig(meth) - 'self'

    @sig
    @wraps(meth)
    def flat_func(*args, **kwargs):
        return meth(*args, **kwargs)

    return flat_func


if __name__ == '__main__':
    openapi_spec = json.loads(argv[1])
    api = HttpClient(openapi_spec=openapi_spec)
    funcs = [
        flatten(api.foo),
        flatten(api.bar),
        flatten(api.confuser),
    ]

    app = dispatch_funcs(funcs)
    app()
